@@ -4,6 +4,8 @@
 ( cd opt/kde/share/doc/HTML/it/ktuberling ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/amor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kdat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kdat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdvi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kgeo ; rm -rf common )
@@ -12,12 +14,12 @@
 ( cd opt/kde/share/doc/HTML/it/kodo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/korn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/korn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksim ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/lisa ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/lisa ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/powerctrl ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/powerctrl ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kalzium ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/katomic ; rm -rf common )
@@ -34,6 +36,10 @@
 ( cd opt/kde/share/doc/HTML/it/kpercentage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcalc ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcron ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kfind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kfind ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kiten ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kiten ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmail ; rm -rf common )
@@ -44,8 +50,12 @@
 ( cd opt/kde/share/doc/HTML/it/kooka ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksame ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/ksysv ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/ksysv ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ktron ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kuser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kuser ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kwin4 ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kwin4 ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/lskat ; rm -rf common )
@@ -76,10 +86,16 @@
 ( cd opt/kde/share/doc/HTML/it/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kioslave ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kioslave ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/flashkard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/flashkard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kaddressbook ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kxconfig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kxconfig ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf qpl-license.html )
@@ -166,10 +182,44 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kalarmd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/cookies ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/desktop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/cache ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/clock ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/email ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/passwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/colors ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/crypto ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kicker-applets ; rm -rf common )
@@ -184,12 +234,16 @@
 ( cd opt/kde/share/doc/HTML/it/keduca ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kicker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kicker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/klines ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmines ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmplot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/knotes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/knotes ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpoker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kruler ; rm -rf common )
@@ -230,6 +284,8 @@
 ( cd opt/kde/share/doc/HTML/it/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kenolaba ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kgpgcertmanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kworldclock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksokoban ; rm -rf common )
@@ -238,7 +294,39 @@
 ( cd opt/kde/share/doc/HTML/it/kteatime ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmathtool ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmathtool ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/pci ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/usb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/nics ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/interrupts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/blockdevices ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/xserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/sound ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/partitions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/pcmcia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/processor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/ioports ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/atlantik ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/atlantik ; ln -sf /opt/kde/share/doc/HTML/it/common common )
